==> nextcloud-18.0.4.tgz: nextcloud/apps/theming/l10n/sq.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Duke ngarkuar pamjen paraprake...",
    "Saved" : "E ruajtur",
    "Admin" : "Admin",
    "a safe home for all your data" : "një vënd i sigurtë për të dhënat e tua ",
    "The given name is too long" : "Emri i dhënë është tepër i gjatë ",
    "The given web address is too long" : "Adresa e dhënë e ueb-it është tepër e gjate ",
    "The given slogan is too long" : "Slogani i dhënë është shumë i gjatë ",
    "The given color is invalid" : "Ngjyra e dhënë është invalide ",
    "The file was uploaded" : "Skedari u ngarkua",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kartela e ngarkuar tejkalon udhëzimin MAX_FILE_SIZE që qe përcaktuar te formulari HTML",
    "No file was uploaded" : "S’u ngarkua kartelë",
    "Missing a temporary folder" : "Mungon një dosje e përkohshme",
    "No file uploaded" : "Asnjë skedar i ngarkuar",
    "Unsupported image type" : "Lloj imazhi i pa suportuar",
    "Theming" : "Duke vendosur theme-n",
    "Open documentation" : "Dokumentacion i hapur",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming bën të mundur për të përshtatur lehtësisht pamjen dhe ndjenjën e instancës suaj dhe klientëve të mbështetur. Kjo do të jetë e dukshme për të gjithë përdoruesit.",
    "Name" : "Emri",
    "Reset to default" : "Rivendos tek të paracaktuarat",
    "Slogan" : "Sllogan",
    "Color" : "Ngjyrë ",
    "Logo" : "Logo",
    "Upload new logo" : "Ngarko logo të re ",
    "Login image" : "Imazhi i hyrjes",
    "Upload new login background" : "Ngarko background të ri hyrjeje",
    "Remove background image" : "Hiqni imazhin në sfond",
    "Advanced options" : "Opsione të avancuara"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.6.tgz: nextcloud/apps/theming/l10n/sq.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Duke ngarkuar pamjen paraprake...",
    "Saved" : "E ruajtur",
    "Admin" : "Admin",
    "a safe home for all your data" : "një vënd i sigurtë për të dhënat e tua ",
    "The given name is too long" : "Emri i dhënë është tepër i gjatë ",
    "The given web address is too long" : "Adresa e dhënë e ueb-it është tepër e gjate ",
    "The given slogan is too long" : "Slogani i dhënë është shumë i gjatë ",
    "The given color is invalid" : "Ngjyra e dhënë është invalide ",
    "The file was uploaded" : "Skedari u ngarkua",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kartela e ngarkuar tejkalon udhëzimin MAX_FILE_SIZE që qe përcaktuar te formulari HTML",
    "No file was uploaded" : "S’u ngarkua kartelë",
    "Missing a temporary folder" : "Mungon një dosje e përkohshme",
    "No file uploaded" : "Asnjë skedar i ngarkuar",
    "Theming" : "Duke vendosur theme-n",
    "Open documentation" : "Dokumentacion i hapur",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming bën të mundur për të përshtatur lehtësisht pamjen dhe ndjenjën e instancës suaj dhe klientëve të mbështetur. Kjo do të jetë e dukshme për të gjithë përdoruesit.",
    "Name" : "Emri",
    "Reset to default" : "Rivendos tek të paracaktuarat",
    "Slogan" : "Sllogan",
    "Color" : "Ngjyrë ",
    "Logo" : "Logo",
    "Upload new logo" : "Ngarko logo të re ",
    "Login image" : "Imazhi i hyrjes",
    "Upload new login background" : "Ngarko background të ri hyrjeje",
    "Remove background image" : "Hiqni imazhin në sfond",
    "Advanced options" : "Opsione të avancuara",
    "Unsupported image type" : "Lloj imazhi i pa suportuar"
},
"nplurals=2; plural=(n != 1);");
